View source: R/futurize_options.R
| futurize_options | R Documentation |
Options for how futures are partitioned and resolved
futurize_options(
seed = FALSE,
globals = TRUE,
packages = NULL,
stdout = TRUE,
conditions = "condition",
scheduling = 1,
chunk_size = NULL,
...
)
seed |
(optional) If TRUE, the random seed, that is, the state of the
random number generator (RNG) will be set such that statistically sound
random numbers are produced (also during parallelization).
If FALSE (default), it is assumed that the future expression neither
needs nor uses random number generation.
To use a fixed random seed, specify a L'Ecuyer-CMRG seed (seven integers)
or a regular RNG seed (a single integer). If the latter, then a
L'Ecuyer-CMRG seed will be automatically created based on the given seed.
Furthermore, if FALSE, then the future will be monitored to make sure it
does not use random numbers. If it does and depending on the value of
option future.rng.onMisuse, the check is
ignored, an informative warning, or error will be produced.
If |
globals |
(optional) a logical, a character vector, or a named list
to control how globals are handled.
For details, see section 'Globals used by future expressions'
in the help for |
packages |
(optional) a character vector specifying packages to be
attached in the R environment evaluating the future, in addition to
packages required by global variables specified or identified via argument
|
stdout |
If TRUE (default), then the standard output is captured,
and re-outputted when |
conditions |
A character string of condition classes to be captured
and relayed. The default is to relay all conditions, including messages
and warnings. To drop all conditions, use |
scheduling |
Average number of futures ("chunks") per worker.
If |
chunk_size |
The average number of elements per future ("chunk").
If |
... |
Additional named options. |
A named list of future options.
Attribute specified is a character vector of future options
that were explicitly specified.
# Default futurize options
str(futurize_options())
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.